@@ -2,17 +2,10 @@ use strict;
 use warnings;
 #use feature qw( say );
 
-package 
-   Games::Sudoku::Trainer::Found_info;
+package
+    Games::Sudoku::Trainer::Found_info;
 
-use version; our $VERSION = qv('0.03');    # PBP
-
-# This package manages a FIFO buffer for scalars. Incoming scalars
-# are added to the buffer, the oldest scalar is returned on request.
-# If the buffer is empty, "undef" is returned. So "undef" shouldn't
-# be presented for addition (this is currently not checked).
-# In spite of its name, Found_info doesn't know anything about the
-# managed scalars.
+use version; our $VERSION = qv('0.01');    # PBP
 
 my @pending;    # all Found_info objects waiting for processing
 
@@ -32,17 +25,17 @@ sub new {
     #    my $self = \%props;
     my $self = $found_ref;
     bless $self, $class;
-
     push @pending, $self;
     return;
 }
 
 # getter for Found_info objects
-#   return the oldest pending Found_info object for processing
+#   return all pending Found_info objects for processing
 #
-sub oldest {
-
-    return shift @pending;
+sub getall {
+    my @process = @pending;
+    @pending = ();
+    return @process;
 }
 
 1;
