@@ -2,38 +2,15 @@ use strict;
 use warnings;
 #use feature qw( say );
 
-# basic Sudoku structures
-# don't panic - all basic Sudoku structures are constant
-package main;
-our @rows;      # row objects		(1 .. 9)
-our @cols;      # col objects		(1 .. 9)
-our @blocks;    # block objects		(1 .. 9)
-our @units;     # all unit objects	(0 .. 26)  rows, columns, and blocks
-our @lines;     # all line objects	(0 .. 17)  rows and columns
-
-sub init_all {
-    use Games::Sudoku::Trainer::Const_structs;
-    use Games::Sudoku::Trainer::Priorities;
-    use Games::Sudoku::Trainer::Found_info;
-    use Games::Sudoku::Trainer::Strategies;
-    use Games::Sudoku::Trainer::Pause;
-    use Games::Sudoku::Trainer::GUI;
-    use Games::Sudoku::Trainer::GUIhist;
-    use Games::Sudoku::Trainer::Write_puzzle;
-    use Games::Sudoku::Trainer::Check_pause;
-}
-
 # basic Sudoku structures
 # don't panic - all basic Sudoku structures are constant
 package main;
 our @cells;    # cell objects		(1 .. 81)
-#our @units;    # all unit objects	(0 .. 26)  rows, columns, and blocks
+our @units;    # all unit objects	(0 .. 26)  rows, colums, and blocks
 
-#package
-#    Games::Sudoku::Trainer::Run;
 package Games::Sudoku::Trainer::Run;
 
-use version; our $VERSION = qv('0.04');    # PBP
+use version; our $VERSION = qv('0.01');    # PBP
 
 use Getopt::Long;
 use Carp;
@@ -179,8 +156,7 @@ sub _init_puzzle {
         # So the user has the chance to select a different puzzle.
         #
         $gamestring =~ s/\n//g;    # ignore newlines
-
-        # ignore whitespace
+                                   # ignore whitespace
         if ( length($gamestring) > 81 ) { $gamestring =~ s/\s//g }
         my $l = length($gamestring);
         if ( $l == 0 ) {
@@ -222,14 +198,14 @@ sub _init_puzzle {
 sub _insert_presets {
     my ( $cell, $digit, $strategy );
     my $found_info_ref;
+    my @found;
 
     # Inform class Cell that we are inserting preset values
     # This delays some error messages until verify
     Games::Sudoku::Trainer::Pause->setMode('in_preset');
-    while (1) {
-    	my $oldest = Games::Sudoku::Trainer::Found_info->oldest();
-		last unless $oldest;
-        $found_info_ref = $oldest;
+    @found = Games::Sudoku::Trainer::Found_info->getall();
+    while (@found) {
+        $found_info_ref = shift(@found);
         ( $cell, $digit, $strategy ) = @$found_info_ref;
         $cell->insert_digit($digit);
         Games::Sudoku::Trainer::GUI::display_cellvalue(
@@ -298,30 +274,30 @@ sub _verify_puzzle {
     return;
 } ## end sub _verify_puzzle
 
-# the main loop of SudokuTrainer
+# the main loop of the Sudoku trainer
 #
 sub _run_puzzle {
 
-    # fetch the oldest find from module Found_info
-    # if no find returned
-    #    call module Strategies to search in the puzzle
-    #    terminate the main loop if nothing found
+    # fetch the next find from @found
     # check whether a pause is requested at this state of the puzzle
     # if yes, pause until the user hits the "Run" button
     # update the internal structures and the displayed board
-    # add the processed find to the history
-    # 
+    #
+    # When this find was the last in @found,
+    #   start the strategies loop to find more values or exclusions
+    # When there is no new find, terminate the main loop
+    #
+    my @found;
     my $found_info_ref;
     my ( $cell, $digit, $strategy );
 
-    while (1) {
-        $found_info_ref = Games::Sudoku::Trainer::Found_info->oldest();
-        unless ($found_info_ref) {
-            Games::Sudoku::Trainer::Strategies::try_strategies();
-		    $found_info_ref = Games::Sudoku::Trainer::Found_info->oldest();
-            last unless $found_info_ref;
-        }
-        $strategy = $found_info_ref->[0];
+    unless (@found) {
+        Games::Sudoku::Trainer::Strategies::try_strategies();
+        @found = Games::Sudoku::Trainer::Found_info->getall();
+    }
+    while (@found) {
+        $found_info_ref = shift(@found);
+        $strategy       = $found_info_ref->[0];
         if ( $found_info_ref->[1] eq 'insert' ) {
             ( $digit, $cell ) = @{ $found_info_ref->[3] };
             next if ( $cell->Value );    # already found
@@ -333,13 +309,16 @@ sub _run_puzzle {
             $cell->insert_digit($digit);
             Games::Sudoku::Trainer::Strategies::full_house($cell);
 
-        } else {                           # exclude cand.s
+        }
+        else {                           # exclude cand.s
 
             Games::Sudoku::Trainer::Check_pause::check_pause($found_info_ref);
             my @exclude_info = @{ $found_info_ref->[3] };
+            my $inform       = '';
             foreach my $info (@exclude_info) {
                 my ( $cell_num, $exclude_cands ) = split( '-', $info );
                 $cell = $cells[$cell_num];
+                $inform .= "$exclude_cands from " . $cell->Name . ', ';
                 foreach my $digit ( split( '', $exclude_cands ) ) {
                     $cell->exclude_candidate($digit);
                 }
@@ -347,7 +326,18 @@ sub _run_puzzle {
         }
         Games::Sudoku::Trainer::GUIhist::add_history($found_info_ref);
     }
-    # the main loop has terminated
+    continue {
+        unless (@found) {
+
+            # last try if not all values found
+            my $not_done = first { $_->Value == 0 } @cells[ 1 .. 81 ];
+            if ($not_done) {
+                Games::Sudoku::Trainer::Strategies::try_strategies();
+                @found = Games::Sudoku::Trainer::Found_info->getall();
+                last if not @found;
+            }
+        }
+    }
 
     if ( ( my $valuecount = grep { $_->Value } @cells[ 1 .. 81 ] ) == 81 ) {
         Games::Sudoku::Trainer::GUI::set_status('Sudoku puzzle is solved');
