@@ -9,16 +9,15 @@ our @cells;     # cell objects		(1 .. 81)
 our @rows;      # row objects		(1 .. 9)
 our @cols;      # col objects		(1 .. 9)
 our @blocks;    # block objects		(1 .. 9)
-our @units;     # all unit objects	(0 .. 26)  rows, columns, and blocks
-our @lines;     # all line objects	(0 .. 17)  rows and columns
+our @units;     # all unit objects	(0 .. 26)  rows, colums, and blocks
+our @lines;     # all line objects	(0 .. 17)  rows and colums
 
 package
     Games::Sudoku::Trainer::Strategies;
 
-use version; our $VERSION = qv('0.04');    # PBP
+use version; our $VERSION = qv('0.01');    # PBP
 
-use List::Util;        # for first
-use List::MoreUtils;   # for uniq and firstidx
+use List::MoreUtils;
 
 # This is the priority loop. All supported strategies (exept Full house)
 # are tried in turn in the sequence of their priorities, until one
@@ -43,14 +42,7 @@ use List::MoreUtils;   # for uniq and firstidx
 #          for action 'exclude': each element has the structure
 #          $cell->Cell_num . '-' . "cand digit"
 #
-
 sub try_strategies {
-	# protect against problems
-	# on an excessive strategy scan after solving a puzzle
-	use List::Util qw(first);
-#	my @candcells = grep {! $_->Value} @cells[1 .. 81];
-	return unless grep {! $_->Value} @cells[1 .. 81];
-
     foreach
       my $strat_func ( @{ Games::Sudoku::Trainer::Priorities::strat_funcs_ref() } )
     {
@@ -65,14 +57,10 @@ sub try_strategies {
 }
 
 sub _bivalue_universal_grave {
-	my @candcells = grep {! $_->Value} @cells[1 .. 81];
-	# protect against the confusing "not unique" message
-	# on an excessive strategy scan after solving a puzzle
-	return unless @candcells;
-
     my $cand3cell;
-    foreach my $cell (@candcells) {
+    foreach my $cell (@cells) {
         next unless $cell;    # skip index 0
+        next if $cell->Value;
         my $cell_cands = $cell->Candidates;
         my $candcount  = length($cell_cands);
         return if $candcount > 3;
@@ -81,7 +69,6 @@ sub _bivalue_universal_grave {
             $cand3cell = $cell;
         }
     }
-
     $cand3cell or die "1\nThis sudoku puzzle is not unique\n";
     my $cell_cands = $cand3cell->Candidates;
     my @cand3 = split( '', $cell_cands );
@@ -906,7 +893,7 @@ sub _cand_cells {
 #	my @all_twins = _collect_2cands(@cell_list);
 #	my @all_twins = _collect_2cands($unit);      # uses the members of the unit
 #		returns list of refs to 2-element arrays:
-#         [cell-obj, string of the 2 cand.s in this cell
+#         cell-obj, string of the 2 cand.s in this cell
 #
 sub _collect_2cands {
     my @cell_list = @_;
@@ -927,13 +914,8 @@ sub _map_filtered {
     @liste = grep { $_ } @liste;    # skip index 0, if required (undef)
     return () unless @liste;
 
-    my @res = eval "map {$mapblock} grep ({$filter} \@liste)";
-#    $@  and  do {
-    if ($@) {
-          my $msg = "    Filter:       $filter\n    Mapblock: $mapblock\n";
-          die "3\nEval error: $@$msg ";    # final ' ' adds trace info
-         };
-    return @res;
+    return eval "map {$mapblock} grep ({$filter} \@liste)"
+      or die "3\nEval error: $@ ";    # final ' ' adds trace info
 }
 
 #-----------------------------------------------------------------------
