@@ -6,7 +6,7 @@ use warnings;
 use Tk;
 use Tk::Balloon;
 
-use version; our $VERSION = qv('0.01.2');    # PBP
+use version; our $VERSION = qv('0.01');    # PBP
 
 # Usage:
 # perl enter_presets.pl
@@ -315,14 +315,17 @@ B<enter_presets> - enter the initial values of a Sudoku puzzle.
 
 =head1 VERSION 
 
-This documentation refers to B<enter_presets> version 0.01.2
+This documentation refers to B<enter_presets> version 0.01
 
 =head1 USAGE 
 
 This program is called internally by 
-B<SudokuTrainer> when
+L<SudokuTrainer|Games::Sudoku::Trainer::pod::sudokutrainer.pod> when 
 the user selects the option I<Enter manually> to create the initial puzzle.
 
+=for ignore
+L<Games::Sudoku::Trainer::pod::sudokutrainer.pod>
+
 =head1 DESCRIPTION 
 
 B<enter_presets> initially displays an empty Sudoku board. Values may be 
@@ -375,7 +378,7 @@ of the trainer.
 
 =head1 SEE ALSO 
 
-The dokumentation for B<SudokuTrainer> (use "perldoc sudokutrainer.pl").
+The dokumentation for L<SudokuTrainer|Games::Sudoku::Trainer::pod::sudokutrainer.pod>.
 
 =head1 DEPENDENCIES 
 
@@ -387,15 +390,17 @@ The dokumentation for B<SudokuTrainer> (use "perldoc sudokutrainer.pl").
 
 =head1 BUGS
 
-Please report any bugs or feature requests to bug-SudokuTrainer [at] rt.cpan.org, 
+Please report any bugs or feature requests to Wittrock@cpan.org, 
+
+=for ignore
 or through the web interface at 
-https://rt.cpan.org/Public/Bug/Report.html?Queue=SudokuTrainer.
+https://rt.cpan.org/Ticket/Create.html?Queue=Games-Sudoku-Trainer.
 
 Patches are welcome.
 
 =head1 AUTHOR
 
-Klaus Wittrock  (Wittrock [at] cpan.org)
+Klaus Wittrock  (Wittrock@cpan.org)
 
 =head1 LICENCE AND COPYRIGHT
 
